pub struct StreamFwder { /* private fields */ }Expand description
Given a stream forwards data to the provided channel.
Implementations
Sourceimpl StreamFwder
impl StreamFwder
Sourcepub fn start(
reader: impl AsyncRead + Unpin + Send + 'static,
file_monitor_addr: Option<ChannelAddr>,
target: OutputTarget,
max_buffer_size: usize,
log_channel: Option<ChannelAddr>,
proc_id: &ProcAddr,
local_rank: usize,
) -> Self
pub fn start( reader: impl AsyncRead + Unpin + Send + 'static, file_monitor_addr: Option<ChannelAddr>, target: OutputTarget, max_buffer_size: usize, log_channel: Option<ChannelAddr>, proc_id: &ProcAddr, local_rank: usize, ) -> Self
Create a new StreamFwder instance, and start monitoring the provided path. Once started Monitor will
- forward logs to log_sender
- forward logs to file_monitor (if available)
- pipe reader to target
- And capture last
max_buffer_sizewhich can be used to inspect file contents viapeek.
pub async fn abort(self) -> (Vec<String>, Result<(), Error>)